@@ -34,7 +34,6 @@
 
 #include <QDateTime>
 #include <qdom.h>
-#include <QFile>
 #include <QDebug>
 #include <QStandardPaths>
 
@@ -128,7 +127,7 @@ FeedStorageMK4Impl::~FeedStorageMK4Impl()
 {
     delete d->storage;
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 void FeedStorageMK4Impl::markDirty()
